==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Shimmer/Shimmer.base.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Watch, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import '../node_modules/core-js/modules/es.number.constructor.js';
import { ShimmerElementsGroup } from './ShimmerElementsGroup/ShimmerElementsGroup.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();
var TRANSITION_ANIMATION_INTERVAL = 200;

var ShimmerBase = function (_BaseComponent) {
  _inherits(ShimmerBase, _BaseComponent);

  var _super = _createSuper(ShimmerBase);

  function ShimmerBase() {
    var _this;

    _classCallCheck(this, ShimmerBase);

    _this = _super.apply(this, arguments);
    _this.contentLoaded = _this.isDataLoaded;
    return _this;
  }

  _createClass(ShimmerBase, [{
    key: "beforeDestroy",
    value: function beforeDestroy() {
      this._async.dispose();
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(newVal, oldVal) {
      var _this2 = this;

      if (newVal === oldVal) return;

      if (this.isDataLoaded) {
        this.lastTimeoutId = this._async.setTimeout(function () {
          _this2.contentLoaded = _this2.isDataLoaded;
        }, TRANSITION_ANIMATION_INTERVAL);
      } else {
        this.contentLoaded = this.isDataLoaded;
      }
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          width = this.width,
          shimmerElements = this.shimmerElements,
          shimmerColors = this.shimmerColors;
      return h("div", {
        "class": classNames.root
      }, [h("div", {
        "style": {
          width: width || '100%'
        },
        "class": classNames.shimmerWrapper
      }, [h("div", {
        "class": classNames.shimmerGradient
      }), h(ShimmerElementsGroup, {
        "attrs": {
          "shimmer-elements": shimmerElements,
          "background-color": shimmerColors && shimmerColors.background
        }
      })])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          styles = this.styles,
          className = this.className,
          shimmerColors = this.shimmerColors;
      return getClassNames(styles, {
        theme: theme,
        isDataLoaded: false,
        className: className,
        transitionAnimationInterval: TRANSITION_ANIMATION_INTERVAL,
        shimmerColor: shimmerColors && shimmerColors.shimmer,
        shimmerWaveColor: shimmerColors && shimmerColors.shimmerWave
      });
    }
  }]);

  return ShimmerBase;
}(BaseComponent);

__decorate([Prop({
  "default": null
}), __metadata("design:type", Object)], ShimmerBase.prototype, "shimmerColors", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], ShimmerBase.prototype, "isDataLoaded", void 0);

__decorate([Prop({
  type: Array,
  "default": function _default() {
    return [];
  }
}), __metadata("design:type", Array)], ShimmerBase.prototype, "shimmerElements", void 0);

__decorate([Prop({
  type: [Number, String],
  "default": null
}), __metadata("design:type", Object)], ShimmerBase.prototype, "width", void 0);

__decorate([Watch('isDataLoaded'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean, Boolean]), __metadata("design:returntype", void 0)], ShimmerBase.prototype, "componentDidUpdate", null);

ShimmerBase = __decorate([Component({
  components: {
    ShimmerElementsGroup: ShimmerElementsGroup
  }
})], ShimmerBase);

export { ShimmerBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Shimmer/Shimmer.base.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Watch, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import 'core-js/modules/es.number.constructor';
import { ShimmerElementsGroup } from './ShimmerElementsGroup/ShimmerElementsGroup.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();
var TRANSITION_ANIMATION_INTERVAL = 200;

var ShimmerBase = function (_BaseComponent) {
  _inherits(ShimmerBase, _BaseComponent);

  var _super = _createSuper(ShimmerBase);

  function ShimmerBase() {
    var _this;

    _classCallCheck(this, ShimmerBase);

    _this = _super.apply(this, arguments);
    _this.contentLoaded = _this.isDataLoaded;
    return _this;
  }

  _createClass(ShimmerBase, [{
    key: "beforeDestroy",
    value: function beforeDestroy() {
      this._async.dispose();
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(newVal, oldVal) {
      var _this2 = this;

      if (newVal === oldVal) return;

      if (this.isDataLoaded) {
        this.lastTimeoutId = this._async.setTimeout(function () {
          _this2.contentLoaded = _this2.isDataLoaded;
        }, TRANSITION_ANIMATION_INTERVAL);
      } else {
        this.contentLoaded = this.isDataLoaded;
      }
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          width = this.width,
          shimmerElements = this.shimmerElements,
          shimmerColors = this.shimmerColors;
      return h("div", {
        "class": classNames.root
      }, [h("div", {
        "style": {
          width: width || '100%'
        },
        "class": classNames.shimmerWrapper
      }, [h("div", {
        "class": classNames.shimmerGradient
      }), h(ShimmerElementsGroup, {
        "attrs": {
          "shimmer-elements": shimmerElements,
          "background-color": shimmerColors && shimmerColors.background
        }
      })])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          styles = this.styles,
          className = this.className,
          shimmerColors = this.shimmerColors;
      return getClassNames(styles, {
        theme: theme,
        isDataLoaded: false,
        className: className,
        transitionAnimationInterval: TRANSITION_ANIMATION_INTERVAL,
        shimmerColor: shimmerColors && shimmerColors.shimmer,
        shimmerWaveColor: shimmerColors && shimmerColors.shimmerWave
      });
    }
  }]);

  return ShimmerBase;
}(BaseComponent);

__decorate([Prop({
  default: null
}), __metadata("design:type", Object)], ShimmerBase.prototype, "shimmerColors", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ShimmerBase.prototype, "isDataLoaded", void 0);

__decorate([Prop({
  type: Array,
  default: function _default() {
    return [];
  }
}), __metadata("design:type", Array)], ShimmerBase.prototype, "shimmerElements", void 0);

__decorate([Prop({
  type: [Number, String],
  default: null
}), __metadata("design:type", Object)], ShimmerBase.prototype, "width", void 0);

__decorate([Watch('isDataLoaded'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean, Boolean]), __metadata("design:returntype", void 0)], ShimmerBase.prototype, "componentDidUpdate", null);

ShimmerBase = __decorate([Component({
  components: {
    ShimmerElementsGroup: ShimmerElementsGroup
  }
})], ShimmerBase);

export { ShimmerBase };
